#ifndef DBCHECK_H_
#define DBCHECK_H_

bool UpgradePhoneDatabaseSchema(void);

#endif

